# This file is part of the Juju GUI, which lets users view and manage Juju
# environments within a graphical interface (https://launchpad.net/juju-gui).
# Copyright (C) 2013 Canonical Ltd.
#
# This program is free software: you can redistribute it and/or modify it under
# the terms of the GNU Affero General Public License version 3, as published by
# the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranties of MERCHANTABILITY,
# SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

"""GUI redirect server handlers."""

from tornado import web


class WaitAndRedirectHandler(web.RequestHandler):
    """Handle the HTTP requests to the redirect server.

    If the Juju GUI is not yet ready, serve a static page.
    If the Juju GUI is ready, permanently redirect to the equivalent HTTP URL
    changing the HTTP port.
    """

    def initialize(self, gui_info, redirect_port):
        """Initialize the handler storing local attributes to be used later.

        The gui_info attribute stores information about the current status of
        the Juju GUI: the same instance is shared as a singleton by all handler
        instances and we expect it to be mutated by other parts of the code
        (i.e see guiredirect.apps.watcher). The redirect_port attribute is the
        HTTP port where to redirect when the GUI is ready.
        """
        self.gui_info = gui_info
        self.redirect_port = redirect_port

    def get(self):
        """Handle GET requests."""
        request = self.request
        if self.gui_info.ready:
            # Remove the request port from the host.
            host = request.host.split(':')[0]
            url = '{}://{}:{}{}'.format(
                request.protocol, host, self.redirect_port, request.uri)
            return self.redirect(url, permanent=True)
        self.render('index.html', **self.gui_info)
